<?php
namespace Teknisa\OPL\Controllers;

use \Zeedhi\Framework\DTO\Request\Row;
use \Zeedhi\Framework\DTO\Response;
use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DataSource\DataSet;
use Exception;
use \Teknisa\OPL\Services\Opl01600ParametrizacaoDoOPLService;

class Opl01600ParametrizacaoDoOPLController extends \Teknisa\GER\Controllers\TeknisaCrud {

  protected $dataSourceName = '';
  protected $crudService;

  public function __construct($crudService, $parameterBag, Opl01600ParametrizacaoDoOPLService $service) {
    $this->crudService  = $crudService;
    $this->service      = $service;
    $this->parameterBag = $parameterBag;
  }

  public function inclusaoAutTipoOperOPL(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->inclusaoAutTipoOperOPL($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function exclusaoAutTipoOperOPL(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->exclusaoAutTipoOperOPL($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function acrAutParamProdSupFili(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->acrAutParamProdSupFili($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function subAutParamProdSupFili(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->subAutParamProdSupFili($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function inclusaoCadAutParamProdSup(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->inclusaoCadAutParamProdSup($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function exclusaoCadAutParamProdSup(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->exclusaoCadAutParamProdSup($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function inclusaoCadAutRelacProdOL(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->inclusaoCadAutRelacProdOL($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  public function exclusaoCadAutRelacProdOL(Row $request, Response $response) {
    $this->service->beginTransaction();
    
    try {
      $row = $request->getRow();
      
      $procedure = $this->service->exclusaoCadAutRelacProdOL($row);
      
      $this->service->realizaCommit();
      
      $response->addDataSet(new DataSet('data', $procedure));
    } catch (\Exception $e) {
      $this->service->realizaRollback();
      
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
}