<?php
namespace Teknisa\OPL\Services;

use \Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Opl01600ParametrizacaoDoOPLService {
  protected $connection;
  protected $newCode;
    
  public function __construct($entityManager, $environment, $newCode) {
    $this->entityManager  = $entityManager;
    $this->connection     = $entityManager->getConnection();
    $this->environment    = $environment;
    $this->newCode        = $newCode;
  }
    
  public function realizaCommit() {
    $this->entityManager->commit();
  }
    
  public function realizaRollback() {
    $this->entityManager->rollBack();
  }
    
  public function beginTransaction() {
    $this->entityManager->beginTransaction();
  }
  
  public function inclusaoAutTipoOperOPL($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_TIPOOPEROPL');
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILIOPELOG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTIPOOPERSAID', Param::PARAM_INPUT, $row['CDTIPOOPERSAID'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTIPOOPERENTR', Param::PARAM_INPUT, $row['CDTIPOOPERENTR'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'I', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdOperador(), Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      $procedure->addParam(new Param('P_CDCLIENTE', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_VRFATODESONERA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDSERIE', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTPOPSACAIXA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTPOPENCAIXA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function exclusaoAutTipoOperOPL($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_TIPOOPEROPL');
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILIOPELOG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTIPOOPERSAID', Param::PARAM_INPUT, 'T', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTIPOOPERENTR', Param::PARAM_INPUT, 'T', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'E', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdOperador(), Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      $procedure->addParam(new Param('P_CDCLIENTE', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_VRFATODESONERA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDSERIE', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTPOPSACAIXA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDTPOPENCAIXA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function acrAutParamProdSupFili($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_PARAMPRODSUP_FILI');
      $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILORIG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_SUBSTITUI', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function subAutParamProdSupFili($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_PARAMPRODSUP_FILI');
      $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILORIG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_SUBSTITUI', Param::PARAM_INPUT, 'S', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function inclusaoCadAutParamProdSup($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_PARAMPRODSUP');
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILIOPELOG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDREGIAO', Param::PARAM_INPUT, $row['CDREGIAO'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, $row['CDGRUPPROD'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDSUBGRPROD', Param::PARAM_INPUT, $row['CDSUBGRPROD'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILISUBGR', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'I', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function exclusaoCadAutParamProdSup($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_PARAMPRODSUP');
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILIOPELOG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDREGIAO', Param::PARAM_INPUT, $row['CDREGIAO'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, $row['CDGRUPPROD'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDSUBGRPROD', Param::PARAM_INPUT, $row['CDSUBGRPROD'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILISUBGR', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'E', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function inclusaoCadAutRelacProdOL($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_RELACPRODOL');
      $procedure->addParam(new Param('P_CDPRODINIOL', Param::PARAM_INPUT, $row['CDPRODINIOL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFINOL', Param::PARAM_INPUT, $row['CDPRODFINOL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'I', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDMARCA', Param::PARAM_INPUT, $row['CDMARCA'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
      
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
  
  public function exclusaoCadAutRelacProdOL($row) {
    try {
      $procedure = new StoredProcedure($this->connection, 'CAD_AUT_RELACPRODOL');
      $procedure->addParam(new Param('P_CDPRODINIOL', Param::PARAM_INPUT, $row['CDPRODINIOL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFINOL', Param::PARAM_INPUT, $row['CDPRODFINOL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_OPERACAO', Param::PARAM_INPUT, 'E', Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_ERROS', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 1));
      $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDMARCA', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
      return $procedure->execute();
    } catch(Exception $e) {
      throw $e;
    }
  }
}