<?php
namespace Financeiro\Logic\AtualizaFluxodeCaixa;

use Financeiro\Entities\Movbancario;
use \Financeiro\Logic\AtualizaFluxodeCaixa\Exception\ExcecaoFluxodeCaixa;
use \Financeiro\Entities\Movfluxo;
use \Geral\Util\DateUtil;
use \Financeiro\Entities\Sdoccorr;
use \Setforms2\Shared\Registry;
use \Geral\Util\Ambiente;
use Setforms2\Shared\ORM\DateTime;

/**
 * Created by JetBrains PhpStorm.
 * User: alanoliveira
 * Date: 06/06/13
 * Time: 17:45
 * To change this template use File | Settings | File Templates.
 */
class FluxodeCaixa
{


    /**
     * @param $cdempresa
     * @param $cdfilial
     * @param $cdclassFina
     * @param $dtMovFluxo
     * @param $valor
     * @param $idtipomov
     * @param string $idOperacao
     * @throws \Exception
     */
    public static function atualizaFluxo($cdempresa, $cdfilial, $cdclassFina,$dtMovFluxo,$valor,$idtipomov,
                                         $idOperacao = 'Entrada', $nrorg)
    {

        if (! in_array($idtipomov,array('R','E','P')))
        {
           ExcecaoFluxodeCaixa::idMovFluxoInv();
        }

         /** @var $movfluxo Movfluxo */
        $movfluxo = Movfluxo::getObjectByWhere('CDCLASSFINA = ? AND CDEMPRESA = ? AND CDFILIAL = ? AND
                                                DTMOVFLUXO = ? AND IDMOVFLUXO = ? AND NRORG = ?' ,
                                                array($cdclassFina,$cdempresa,$cdfilial,
                                                      $dtMovFluxo,$idtipomov,$nrorg));


        if ((bool)$movfluxo === true) // existe MovFluxo
        {
            // Altera o valor do Moviumento do FLuxo
            if ($idOperacao == 'Entrada')
            {
               $movfluxo->setVrentmfluxo($movfluxo->getVrentmfluxo()+floatval($valor));
            }else{
                $movfluxo->setVrsaimfluxo(($movfluxo->getVrsaimfluxo()+floatval($valor)));
            }

        }else
        {
             //Converte para o tipo de data a dtmovfluxo caso este seja de outro tipo
             if (($dtMovFluxo instanceof \Setforms2\Shared\ORM\DateTime) === false) {
                $dtMovFluxo = DateUtil::getDataDeString($dtMovFluxo);
             }
             // 00:00:00
             $dtMovFluxo = DateUtil::truncateData($dtMovFluxo);

            //Insere Movimento de Fluxo
            $movfluxo = new Movfluxo();
            $movfluxo->setCdclassfina($cdclassFina);
            $movfluxo->setCdempresa($cdempresa);
            $movfluxo->setCdfilial($cdfilial);
            $movfluxo->setDtmovfluxo($dtMovFluxo);
            $movfluxo->setIdmovfluxo($idtipomov);
            $movfluxo->setDtinclusao(\Geral\Util\DateUtil::getDataAtual());
            $movfluxo->setNrorg($nrorg);

            if($idOperacao == 'Entrada')
            {
               $movfluxo->setVrentmfluxo($valor);
               $movfluxo->setVrsaimfluxo(0);
            }else{
                $movfluxo->setVrsaimfluxo($valor);
                $movfluxo->setVrentmfluxo(0);
            }

        }

        try {
            $movfluxo->persist();
            \Setforms2\Shared\Registry::getEntityManager()->flush();
        }
        catch (\Exception $e) {
            throw $e;
        }

    }

    /**
     * @param $cdreducont
     * @param $dtsdoccorr
     * @param $vrsdoccorr
     * @param string $iddebcred C - CRÉDITO / D - DÉBITO
     * @throws \Exception
     */
    public static function atualizaSaldoContCorr($cdreducont, $dtsdoccorr, $vrsdoccorr, $iddebcred = 'C')
    {
        try {

            $dtsdoccorr = self::formataData($dtsdoccorr);

            $ultimosaldo = 0;
            $boSaldoImplant = false;

            if($iddebcred == 'D')
                $vrsdoccorr = $vrsdoccorr * -1;

            //Busca Todos os saldos maiores ou iguais a data do movimento
            /** @var $saldo Sdoccorr */
            $saldos = Sdoccorr::getObjectsByWhere('CDREDUCONT = ? AND DTSDOCCORR >= ? ORDER BY DTSDOCCORR',
                                               array($cdreducont, $dtsdoccorr));

            /** @var $rep \Financeiro\Repositories\Sdoccorr */
            $rep = Sdoccorr::getRepository();
            $saldoInicial = $rep->getSaldoAnterior(Ambiente::getNrorg(), $cdreducont, $dtsdoccorr);

            //Se nao houver saldo para a conta insere o mesmo
            if(! $saldos){
                self::insereSaldo($cdreducont,$dtsdoccorr,round($saldoInicial + $vrsdoccorr,2));
            }
            else{
                //Verifica se possui saldo para a data passada por parámetro caso não possua inclui o saldo
                $saldo = $saldos[0];
                if($saldo->getDtsdoccorr()->format('d/m/Y') != $dtsdoccorr->format('d/m/Y'))
                {
                    //Busca o saldo da maior data anterior a data do movimento
                    /** @var $rep \Financeiro\Repositories\Sdoccorr */
                    $rep = Sdoccorr::getRepository();
                    $saldoInicial = $rep->getSaldoAnterior(Ambiente::getNrorg(),$cdreducont,$dtsdoccorr);

                    //Insere o saldo para a data de movimento
                    self::insereSaldo($cdreducont,$dtsdoccorr,round($saldoInicial + $vrsdoccorr,2));
                }

                /** @var $saldo Sdoccorr  */
                foreach($saldos as $saldo){

                    if(! $saldo->getVrsdoimpla()){

                        if($boSaldoImplant){
                            $saldo->setVrsdoccorr(round($ultimosaldo + $vrsdoccorr,2));
                            $ultimosaldo = round($ultimosaldo + $vrsdoccorr,2);
                        }
                        else
                            $saldo->setVrsdoccorr(round($saldo->getVrsdoccorr() + $vrsdoccorr,2));
                    }
                    else
                    {
                        $boSaldoImplant = true;
                        $saldo->setVrsdoccorr($saldo->getVrsdoimpla());
                        $ultimosaldo = $saldo->getVrsdoimpla();
                    }
                    $saldo->persist();
                }
            }

            Registry::getEntityManager()->flush();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function evoluiSaldoImplantacao($cdreducont, $dtsdoccorr, $nrorg, $valor, $idOperacao = 'C'){
        try {
            if($idOperacao == 'D')
                $valor = -$valor;
            $saldos = Sdoccorr::getObjectsByWhere('CDREDUCONT = ? AND DTSDOCCORR > ? AND NRORG = ?', array($cdreducont, $dtsdoccorr, $nrorg));
            if($saldos){
                /** @var $saldo Sdoccorr */
                foreach($saldos as $saldo){
                    $saldo->setVrsdoccorr(round($saldo->getVrsdoccorr() + $valor, 2));
                    $saldo->persist();
                }
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function evoluiSaldoImplantacaoExclusao($cdreducont, $nrorg, $dtsdoccorr, $valor){
        try {
            $movimentos = Movbancario::getObjectsByWhere('NRORG = ? AND CDREDUCONT = ? AND DTMOVBANC = ?', array($nrorg, $cdreducont, $dtsdoccorr));
            $valorTotal = 0;
            /** @var $movimento Movbancario */
            foreach ($movimentos as $movimento) {
                if ($movimento->getIdmovbanc() == 'C')
                    $valorTotal += $movimento->getVrmovbanc();
                else
                    $valorTotal -= $movimento->getVrmovbanc();
            }

            $valor = $valorTotal - $valor;
            self::insereSaldo($cdreducont, self::formataData($dtsdoccorr), $valorTotal);
            self::evoluiSaldoImplantacao($cdreducont, $dtsdoccorr, $nrorg, $valor);
            Registry::getEntityManager()->flush();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function insereSaldo($cdreducont, $dtsdoccorr, $saldo){
        $novosaldo = new Sdoccorr();
        $novosaldo->setNrorg(Ambiente::getNrorg());
        $novosaldo->setDtinclusao(DateUtil::getDataAtual());
        $novosaldo->setCdreducont($cdreducont);
        $novosaldo->setDtsdoccorr($dtsdoccorr);
        $novosaldo->setVrsdoccorr($saldo);
        $novosaldo->persist();
    }

    public static function formataData($data){
        if(strlen($data) == 19)
            $data = DateUtil::truncateString($data);
        $data = DateUtil::getDatadeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }

}